UI Color Picker — CKEditor Sample

# CKEditor Samples » UI Color

This sample shows how to automatically replace `<textarea>` elements with a CKEditor instance with an option to change the color of its user interface.
Note:The UI skin color feature depends on the CKEditor skin compatibility. The Moono and Kama skins are examples of skins that work with it.

This editor instance has a UI color value defined in configuration to change the skin color, To specify the color of the user interface, set the `uiColor` property:

    CKEDITOR.replace( 'textarea_id', {
    	uiColor: '#14B8C4'
    });

Note that `textarea_id` in the code above is the `id` attribute of the `<textarea>` element to be replaced.

<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>